# gemini_helper/core.py

import os
from dotenv import load_dotenv
from agents import AsyncOpenAI, OpenAIChatCompletionsModel , set_tracing_disabled

def get_gemini_model(model_name="gemini-2.0-flash"):
    load_dotenv()
    set_tracing_disabled(True)
    gemini_api_key = os.getenv("GEMINI_API_KEY")
    if not gemini_api_key:
        raise ValueError("GEMINI_API_KEY not found in .env file")
    
    provider = AsyncOpenAI(
        api_key = gemini_api_key,
        base_url = "https://generativelanguage.googleapis.com/v1beta/openai"
    )

    model = OpenAIChatCompletionsModel(
        model = model_name,
        openai_client = provider
    )
    return model


from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name='gemini-helper',
    version='0.1',
    packages=find_packages(),
    install_requires=[
        'python-dotenv',
        'openai-agent-sdk',
    ],
    description='Gemini SDK helper for OpenAI Agent SDK',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='Huriya Syed',
    author_email='huriyasyed462@gmail.com',
    url='https://github.com/huriyasyed/gemini-helper',
    license='MIT', 
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
        "License :: OSI Approved :: MIT License"
    ],
    python_requires='>=3.7',
)
